==> tib-0.6.4.tgz: package/lib/tib-selenium.js <==
'use strict';

require('path');
require('hable');
require('signal-exit');
const __chunk_1 = require('./tib-chunk.js');
require('os');
require('child_process');
require('tree-kill');
require('vue-template-compiler');
require('@babel/core');
require('@babel/parser');
require('./tib-chunk2.js');
require('./tib-chunk3.js');
const index = require('./tib-index.js');
const __chunk_4 = require('./tib-chunk4.js');
require('fs');
const __chunk_5 = require('./tib-chunk5.js');

class ChromeSeleniumBrowser extends __chunk_4.SeleniumLogging(index.default) {
  constructor(config) {
    super(config);

    this.setBrowser('chrome');

    this.hook('selenium:build:before', async (builder) => {
      let path = process.env.CHROME_EXECUTABLE_PATH;

      if (!path) {
        path = new __chunk_5.ChromeDetector().detect();
      }

      if (!path) {
        throw new __chunk_1.BrowserError(this, 'Could not find Chrome executable path')
      }

      const configArguments = [
        'no-sandbox',
        'disable-setuid-sandbox',
        ...this.config.browserArguments
      ];

      const options = new ChromeSeleniumBrowser.Options();
      options.setChromeBinaryPath(path);
      options.addArguments(...configArguments);

      await this.callHook('selenium:build:options', options, builder);

      builder.setChromeOptions(options);
    });
  }

  setHeadless() {
    super.setHeadless();
    this.config.browserArguments.push('disable-gpu');
  }

  async _loadDependencies() {
    super._loadDependencies();

    if (!ChromeSeleniumBrowser.chromedriver) {
      ChromeSeleniumBrowser.chromedriver = await this.loadDependency('chromedriver');
    }

    if (!ChromeSeleniumBrowser.Options) {
      const { Options } = await this.loadDependency('selenium-webdriver/chrome');
      ChromeSeleniumBrowser.Options = Options;
    }
  }
}

exports.default = ChromeSeleniumBrowser;

==> tib-0.7.0.tgz: package/lib/tib-selenium.js <==
'use strict';

require('path');
require('hable');
require('signal-exit');
require('os');
require('child_process');
require('tree-kill');
const browserstackLocal = require('./tib-browserstack-local.js');
require('vue-template-compiler');
require('fs');
require('util');
require('events');
require('assert');
require('crypto');
require('webpack');
require('@babel/core');
require('@babel/parser');
require('./tib-browser.js');
require('http');
require('./tib-webpage.js');
const index = require('./tib-index.js');
const logging = require('./tib-logging.js');
const chrome = require('./tib-chrome.js');

class ChromeSeleniumBrowser extends logging.SeleniumLogging(index.default) {
  constructor(config) {
    super(config);

    this.setBrowser('chrome');

    this.hook('selenium:build:before', async (builder) => {
      let path = process.env.CHROME_EXECUTABLE_PATH;

      if (!path) {
        path = new chrome.ChromeDetector().detect();
      }

      if (!path) {
        throw new browserstackLocal.BrowserError(this, 'Could not find Chrome executable path')
      }

      const configArguments = [
        'no-sandbox',
        'disable-setuid-sandbox',
        ...this.config.browserArguments
      ];

      const options = new ChromeSeleniumBrowser.Options();
      options.setChromeBinaryPath(path);
      options.addArguments(...configArguments);

      await this.callHook('selenium:build:options', options, builder);

      builder.setChromeOptions(options);
    });
  }

  setHeadless() {
    super.setHeadless();
    this.config.browserArguments.push('disable-gpu');
  }

  async _loadDependencies() {
    super._loadDependencies();

    if (!ChromeSeleniumBrowser.chromedriver) {
      ChromeSeleniumBrowser.chromedriver = await this.loadDependency('chromedriver');
    }

    if (!ChromeSeleniumBrowser.Options) {
      const { Options } = await this.loadDependency('selenium-webdriver/chrome');
      ChromeSeleniumBrowser.Options = Options;
    }
  }
}

exports.default = ChromeSeleniumBrowser;
